@@ -21,20 +21,17 @@
 #include "autotests.h"
 #include "device.h"
 #include "adapter.h"
+#include "battery.h"
 #include "mediaplayer.h"
 #include "mediaplayertrack.h"
+#include "mediatransport.h"
 #include "bluezqt_dbustypes.h"
 
-#include <QDir>
 #include <QDebug>
 #include <QEventLoop>
 #include <QCoreApplication>
 
 #include <QTest>
-#include <QDBusReply>
-#include <QDBusMetaType>
-#include <QDBusInterface>
-#include <QDBusPendingCall>
 #include <QDBusServiceWatcher>
 #include <QDBusConnectionInterface>
 
@@ -49,6 +46,8 @@ public:
 
     void exec();
 
+    bool foundFakeBluez() const { return !m_fakebluezPath.isEmpty(); }
+
 private Q_SLOTS:
     void processError(QProcess::ProcessError error);
     void processFinished(int code, QProcess::ExitStatus status);
@@ -60,7 +59,7 @@ private:
 
 StartJob::StartJob()
     : QObject(nullptr)
-    , m_fakebluezPath(QFINDTESTDATA("fakebluez/fakebluez"))
+    , m_fakebluezPath(QCoreApplication::applicationDirPath() + QStringLiteral("/fakebluez"))
 {
 }
 
@@ -124,6 +123,7 @@ void FakeBluez::start()
     }
 
     StartJob job;
+    QVERIFY(job.foundFakeBluez());
     job.exec();
 }
 
@@ -177,7 +177,9 @@ void Autotests::registerMetatypes()
 {
     qRegisterMetaType<BluezQt::DevicePtr>("DevicePtr");
     qRegisterMetaType<BluezQt::AdapterPtr>("AdapterPtr");
+    qRegisterMetaType<BluezQt::BatteryPtr>("BatteryPtr");
     qRegisterMetaType<BluezQt::MediaPlayerPtr>("MediaPlayerPtr");
+    qRegisterMetaType<BluezQt::MediaTransportPtr>("MediaTransportPtr");
 }
 
 void Autotests::verifyPropertiesChangedSignal(const QSignalSpy &spy, const QString &propertyName, const QVariant &propertyValue)
