@@ -46,7 +46,7 @@ class BLUEZQT_EXPORT Device : public QObject
     Q_OBJECT
 
     Q_PROPERTY(QString ubi READ ubi)
-    Q_PROPERTY(QString address READ address)
+    Q_PROPERTY(QString address READ address NOTIFY addressChanged)
     Q_PROPERTY(QString name READ name WRITE setName NOTIFY nameChanged)
     Q_PROPERTY(QString friendlyName READ friendlyName NOTIFY friendlyNameChanged)
     Q_PROPERTY(QString remoteName READ remoteName NOTIFY remoteNameChanged)
@@ -62,8 +62,10 @@ class BLUEZQT_EXPORT Device : public QObject
     Q_PROPERTY(bool connected READ isConnected NOTIFY connectedChanged)
     Q_PROPERTY(QStringList uuids READ uuids NOTIFY uuidsChanged)
     Q_PROPERTY(QString modalias READ modalias NOTIFY modaliasChanged)
+    Q_PROPERTY(BatteryPtr battery READ battery NOTIFY batteryChanged)
     Q_PROPERTY(InputPtr input READ input NOTIFY inputChanged)
     Q_PROPERTY(MediaPlayerPtr mediaPlayer READ mediaPlayer NOTIFY mediaPlayerChanged)
+    Q_PROPERTY(MediaTransportPtr mediaTransport READ mediaTransport NOTIFY mediaTransportChanged)
     Q_PROPERTY(AdapterPtr adapter READ adapter)
 
 public:
@@ -296,6 +298,14 @@ public:
      */
     QString modalias() const;
 
+    /**
+     * Returns the battery interface for the device.
+     *
+     * @return null if device has no battery
+     * @since 5.66
+     */
+    BatteryPtr battery() const;
+
     /**
      * Returns the input interface for the device.
      *
@@ -315,6 +325,16 @@ public:
      */
     MediaPlayerPtr mediaPlayer() const;
 
+    /**
+     * Returns the media transport interface for the device.
+     *
+     * Only devices with connected appropriate profile will
+     * have valid media transport interface.
+     *
+     * @return null if device have no media transport
+     */
+    MediaTransportPtr mediaTransport() const;
+
     /**
      * Returns an adapter that discovered this device.
      *
@@ -399,7 +419,7 @@ public Q_SLOTS:
     /**
      * Cancels a pairing with the device.
      *
-     * This method can be used to cancel pairing operation inititated with pair().
+     * This method can be used to cancel pairing operation initiated with pair().
      *
      * Possible errors: PendingCall::DoesNotExist, PendingCall::Failed
      *
@@ -423,6 +443,11 @@ Q_SIGNALS:
      */
     void nameChanged(const QString &name);
 
+    /**
+     * Indicates that device's address have changed.
+     */
+    void addressChanged(const QString &address);
+
     /**
      * Indicates that device's friendly name have changed.
      */
@@ -493,6 +518,11 @@ Q_SIGNALS:
      */
     void modaliasChanged(const QString &modalias);
 
+    /**
+     * Indicates that device's battery has changed.
+     */
+    void batteryChanged(BatteryPtr battery);
+
     /**
      * Indicates that device's input have changed.
      */
@@ -503,6 +533,11 @@ Q_SIGNALS:
      */
     void mediaPlayerChanged(MediaPlayerPtr mediaPlayer);
 
+    /**
+     * Indicates that device's media transport have changed.
+     */
+    void mediaTransportChanged(MediaTransportPtr mediaTransport);
+
 private:
     explicit Device(const QString &path, const QVariantMap &properties, AdapterPtr adapter);
 
